@@ -87,11 +87,11 @@ jagsUI <- jags <- function(data,inits=NULL,parameters.to.save,model.file,n.chain
   output$random.seed <- seed
   output$parallel <- parallel
   output$bugs.format <- bugs.format
-  output$DIC <- DIC
+  output$calc.DIC <- DIC
   
   #Classify final output object
   class(output) <- 'jagsUI'
   
   return(output)
   
-}
\ No newline at end of file
+}
